[Durian-svn] [2740] Fixes for last commit, and some comment/instruction tweaks.

brecht institute at blender.org
Fri Apr 30 23:05:17 CEST 2010


Revision: 2740
          https://blenderinstitute.dyndns.org/durian-svn/?do=log&project=durian&path=/&rev=2740
Author:   brecht
Date:     2010-04-30 23:05:16 +0200 (Fri, 30 Apr 2010)
Log Message:
-----------
Fixes for last commit, and some comment/instruction tweaks.

Modified Paths:
--------------
    frm/master_ui.py
    frm/new_master.py

Modified: frm/master_ui.py
===================================================================
--- frm/master_ui.py	2010-04-30 20:01:17 UTC (rev 2739)
+++ frm/master_ui.py	2010-04-30 21:05:16 UTC (rev 2740)
@@ -313,9 +313,15 @@
 
             # instructions
             section("Temporary Instructions")
-            output("* Don't submit the same files as on the other farm here, it will mess up.")
-            output("* Don't add the render nodes as slaves, will not work correct.")
+            output("<ul>")
+            output("<li>Don't submit the same files as on the other farm here, it will mess up.</li>")
+            output("<li>Don't add the render nodes as slaves, will not work correct.</li>")
+            output("<li>Rerendering scenes that already have frames need those manually moved or removed.</li>")
+            output("<li>Only works correct with relative paths, otherwise may use older/newer files from your checkout.</li>")
+            output("</ul>")
 
+            output("<br/>\n")
+
             # jobs
             section("Jobs")
             table_begin("File", "Revision", "Quality", "Status", "Progress", "Priority", "Enabled", "")

Modified: frm/new_master.py
===================================================================
--- frm/new_master.py	2010-04-30 20:01:17 UTC (rev 2739)
+++ frm/new_master.py	2010-04-30 21:05:16 UTC (rev 2740)
@@ -3,13 +3,11 @@
 # TODO
 # * auto-generate avis after job is done, non-blocking
 # * detect crashes so it does not get stuck on these frames
-# * do svn updates on the slave instead of rsync with master
-# * re-enable svn update
-# * fix multiple nodes updating movie files
+# * svn updates on slaves are unreliable...
 # * backup old frames before starting a new job
 # * remove .exrs to restart job
 # * rsync is not killed currently
 # * address already in use on kill
 
 import os
 import time
@@ -195,12 +193,12 @@
 
     touch_busy(ip)
     # do remote rsync
-    remote_command(ip, os.path.join(FARM_DIR, "new_node_update_movie.sh"))
+    remote_command(ip, os.path.join(FARM_DIR, "new_node_update_movie.sh") + " " + job.revision)
 
 def update_frames(ip, job, frame):
     # print("render jobs")
     touch_busy(ip)
-    FARM_DIR_LOCAL = FARM_DIR.replace("/shared/software/durian_farm", "/d") # HACK
+    FARM_DIR_LOCAL = "/media/data/durian_farm_svn"
     remote_command(ip, os.path.join(FARM_DIR, "new_node_update_frames.sh") + " " + os.path.join(FARM_DIR_LOCAL, job.id) + " " + str(frame))
 
 def stage_in():
@@ -3,13 +3,11 @@
 # * backup old frames before starting a new job
 # * remove .exrs to restart job
-# * rsync is not killed currently
-# * address already in use on kill
+# * svn update is not killed currently
+# * httpd address already in use happens sometimes on kill
 
 import os



More information about the Durian-svn mailing list